Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(326)

Unified Diff: net/http/http_cache.h

Issue 2671793002: Correct handling of ERR_CACHE_LOCK_TIMEOUT for read only transactions. (Closed)
Patch Set: Feedback addressed. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | net/http/http_cache.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/http_cache.h
diff --git a/net/http/http_cache.h b/net/http/http_cache.h
index 2aae2fcf27e1cc0aed6fcbbe3b73eb3c3d293708..76f1d68f051e8190c8eebad353fe4c7464729c3f 100644
--- a/net/http/http_cache.h
+++ b/net/http/http_cache.h
@@ -188,11 +188,9 @@ class NET_EXPORT HttpCache : public HttpTransactionFactory,
// referred to by |url| and |http_method|.
void OnExternalCacheHit(const GURL& url, const std::string& http_method);
- // Causes all transactions created after this point to effectively bypass
- // the cache lock whenever there is lock contention.
- void BypassLockForTest() {
- bypass_lock_for_test_ = true;
- }
+ // Causes all transactions created after this point to simulate lock timeout
+ // and effectively bypass the cache lock whenever there is lock contention.
+ void SimulateCacheLockTimeout() { bypass_lock_for_test_ = true; }
// Causes all transactions created after this point to generate a failure
// when attempting to conditionalize a network request.
« no previous file with comments | « no previous file | net/http/http_cache.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698